@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
-from matos_aws_provider.lib import factory
 from typing import Any, Dict
+from matos_aws_provider.lib import factory
 from matos_aws_provider.lib.base_provider import BaseProvider
 
 
 class AwsConfigBase(BaseProvider):
+    """Aws config plugin"""
     def __init__(
         self,
         resource: Dict,
@@ -35,4 +36,5 @@ class AwsConfigBase(BaseProvider):
 
 
 def register() -> None:
+    """Register plugin"""
     factory.register("config_service", AwsConfigBase)
