@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
-
-from matos_aws_provider.lib import factory
 from typing import Any, Dict
+from matos_aws_provider.lib import factory
 from matos_aws_provider.lib.base_provider import BaseProvider
 
 
 class AwsElasticsearch(BaseProvider):
+    """AWS elastic search plugin"""
     def __init__(self, resource: Dict, **kwargs) -> None:
         """
         Construct elastic search service
@@ -38,10 +38,12 @@ class AwsElasticsearch(BaseProvider):
         return resource
 
     def describe_elasticsearch_domain(self, domain_name):
+        """Describe es domain"""
         resp = self.conn.describe_elasticsearch_domain(DomainName=domain_name)
         del resp["ResponseMetadata"]
         return resp.get("DomainStatus")
 
 
 def register() -> Any:
+    """Register plugin"""
     factory.register("elasticsearch", AwsElasticsearch)
