@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
-
-from matos_aws_provider.lib import factory
 from typing import Any, Dict
+from matos_aws_provider.lib import factory
 from matos_aws_provider.lib.base_provider import BaseProvider
 
 
 class AwsOpenSearch(BaseProvider):
+    """AWS open search"""
     def __init__(self, resource: Dict, **kwargs) -> None:
         """
         Construct open search service
@@ -39,4 +39,5 @@ class AwsOpenSearch(BaseProvider):
 
 
 def register() -> Any:
+    """Register plugin"""
     factory.register("opensearch", AwsOpenSearch)
